package com.supervision.service.impl;

import cn.hutool.core.lang.Assert;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.lock.annotation.Lock4j;
import com.supervision.service.DiagnoseHallService;
import com.supervision.service.MedicalRecService;
import com.supervision.service.ProcessService;
import com.supervision.vo.manage.MedicalRecPageResVO;
import com.supervision.vo.result.DiagnoseProcessReqVo;
import com.supervision.vo.result.DiagnoseProcessResVo;
import com.supervision.usermanage.UserResourceCheck;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;


@Service
@RequiredArgsConstructor
@Slf4j
public class DiagnoseHallServiceImpl implements DiagnoseHallService {

    private final UserResourceCheck userResourceCheck;

    private final ProcessService processService;

    private final MedicalRecService medicalRecService;

    @Lock4j(name = "achieveDiagnoseResource")
    @Override
    public boolean achieveDiagnoseResource() {
        // 如果小于数字人最大连接数,则可以连接
        return userResourceCheck.achieveDiagnoseResource();
    }

    @Override
    public IPage<DiagnoseProcessResVo> queryDiagnoseProcessPageList(Integer pageNum, Integer pageSize,
                                                                   DiagnoseProcessReqVo diagnoseProcessReqVo) {
        Assert.notEmpty(diagnoseProcessReqVo.getUserId(),"用户id不允许为空");

        return processService.queryUserDiagnoseProcessPageList(new Page<>(pageNum,pageSize),diagnoseProcessReqVo);
    }

    @Override
    public IPage<MedicalRecPageResVO> queryMedicalRecPageList(Integer pageNum, Integer pageSize) {


        return medicalRecService.queryMedicalRecManagePage(null, null, null, pageNum, pageSize);
    }


}
