package com.supervision.service.impl;

import cn.hutool.core.lang.Assert;
import com.supervision.model.Process;
import com.supervision.model.ProcessMedical;
import com.supervision.service.MedicalRecordService;
import com.supervision.service.ProcessMedicalService;
import com.supervision.service.ProcessService;
import com.supervision.vo.ask.ProcessMedicalResVo;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;


@Service
@RequiredArgsConstructor
@Slf4j
public class MedicalRecordServiceImpl implements MedicalRecordService {

    private final ProcessMedicalService processMedicalService;

    private final ProcessService processService;

    @Override
    public boolean saveMedicalRecord(ProcessMedical processMedical) {

        saveAssert(processMedical);

        return processMedicalService.save(processMedical);
    }

    @Override
    public ProcessMedicalResVo findByProcessId(String processId) {

        Assert.notEmpty(processId,"流程id不允许为空");

        return processMedicalService.findByProcessId(processId);
    }

    @Override
    public boolean updateMedicalRecord(ProcessMedical processMedical) {

        Assert.notEmpty(processMedical.getId(),"id 不能为空");

        return processMedicalService.updateById(processMedical);
    }

    private void saveAssert(ProcessMedical processMedical){
        Assert.notEmpty(processMedical.getProcessId(),"流程id不为空");

        Process process = processService.getById(processMedical.getProcessId());
        Assert.notNull(process,"流程数据不存在");

        processMedical.setMedicalRecId(process.getMedicalRecId());
        processMedical.setPatientId(process.getPatientId());

        Integer count = processMedicalService.lambdaQuery().eq(ProcessMedical::getProcessId, processMedical.getProcessId()).count();
        Assert.isFalse(count > 0,"当前实例已经存在电子病例信息");
    }
}
